==> haskell-xml-hamlet-0.4.1.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.4.1.1
id: xml-hamlet-0.4.1.1-7xfNBeGMskB2KtKlxRg0H3
key: xml-hamlet-0.4.1.1-7xfNBeGMskB2KtKlxRg0H3
license: BSD3
maintainer: michael@snoyman.com
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
abi: 6ccc93fdd998c730e1467db13011d9bf
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/xml-hamlet-0.4.1.1
hs-libraries: HSxml-hamlet-0.4.1.1-7xfNBeGMskB2KtKlxRg0H3
depends:
    base-4.10.0.0 shakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk
    xml-conduit-1.6.0-F5S5bF0qUyLelzQQgHOtm
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz template-haskell-2.12.0.0
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh containers-0.5.10.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             shakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk=e198e94aba8c6865bbd32c1e03fae51b
             xml-conduit-1.6.0-F5S5bF0qUyLelzQQgHOtm=9a49a1e922a53c712522f435093afb9c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=42480b67fee41ad692110e11eaac57c4
             template-haskell-2.12.0.0=612ee923b47f5e11502cef08338c9f82
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=ec025cd9e2938e26fbdb8853642eb58e
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.4.1.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.4.1.1
id: xml-hamlet-0.4.1.1-JZZodh6sItM52gIKeNYgWg
key: xml-hamlet-0.4.1.1-JZZodh6sItM52gIKeNYgWg
license: BSD3
maintainer: michael@snoyman.com
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
abi: ebae8b87cc95424d53ca3939ca624993
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/xml-hamlet-0.4.1.1
hs-libraries: HSxml-hamlet-0.4.1.1-JZZodh6sItM52gIKeNYgWg
depends:
    base-4.10.0.0 shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi
    xml-conduit-1.6.0-62u0Ld0g8V2oBOe0ChvET
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz template-haskell-2.12.0.0
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh containers-0.5.10.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi=d0814b475354dc774cee8fd548e0d047
             xml-conduit-1.6.0-62u0Ld0g8V2oBOe0ChvET=b0077bed96c3485cc8e1dfbd50633e49
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=42480b67fee41ad692110e11eaac57c4
             template-haskell-2.12.0.0=612ee923b47f5e11502cef08338c9f82
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=ec025cd9e2938e26fbdb8853642eb58e
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
